@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::MITHALDU;
-our $VERSION = '1.150511'; # VERSION
+our $VERSION = '1.150512'; # VERSION
 
 # Dependencies
 use autodie 2.00;
@@ -200,6 +200,8 @@ sub configure {
   my $is_release = grep /^release$/, @ARGV;
   $version_provider = [ 'AutoVersion' => { major => $self->major_version } ] if $is_release;
 
+  my @on_release_files = qw/dist.ini Changes README.pod META.json Makefile.PL/;
+
   my @plugins = (
 
   # version number
@@ -275,7 +277,7 @@ sub configure {
   # before release
     [ 'Git::Check' =>
       {
-        allow_dirty => [qw/dist.ini Changes README.pod META.json Makefile.PL/]
+        allow_dirty => [@on_release_files]
       }
     ],
     'CheckPrereqsIndexed',
@@ -293,7 +295,7 @@ sub configure {
     # commit dirty Changes, dist.ini, README.pod, META.json
     [ 'Git::Commit' =>
       {
-        allow_dirty => [qw/dist.ini Changes README.pod META.json/]
+        allow_dirty => [@on_release_files]
       }
     ],
     [ 'Git::Tag' => { tag_format => $self->tag_format } ],
@@ -336,7 +338,7 @@ Dist::Zilla::PluginBundle::MITHALDU - Dist::Zilla configuration the way MITHALDU
 
 =head1 VERSION
 
-version 1.150511
+version 1.150512
 
 =head1 SYNOPSIS
 
